@@ -8,6 +8,7 @@
 from __future__ import absolute_import
 from decimal import Decimal as MyDecimal, ROUND_HALF_EVEN
 from functools import wraps
+import inspect
 
 from marshmallow import validate, utils
 from marshmallow.base import FieldABC, SerializerABC
@@ -377,6 +378,10 @@ class Integer(Number):
 
     num_type = int
 
+    def __init__(self, default=0, attribute=None, as_string=False, error=None, **kwargs):
+        self.as_string = as_string
+        super(Number, self).__init__(default=default, attribute=attribute,
+            error=error, **kwargs)
 
 class Boolean(Raw):
     '''A boolean field.'''
@@ -460,9 +465,10 @@ class DateTime(Raw):
 
 class LocalDateTime(DateTime):
     """A formatted datetime string in localized time, relative to UTC.
-        ex. ``"Sun, 10 Nov 2013 08:23:45 -0600"``
-    Takes the same arguments as :class:`DateTime <marshmallow.fields.DateTime>`.
 
+        ex. ``"Sun, 10 Nov 2013 08:23:45 -0600"``
+
+    Takes the same arguments as :class:`DateTime <marshmallow.fields.DateTime>`.
     """
     localtime = True
 
@@ -569,6 +575,19 @@ class Email(Raw):
         return validate.email(value)
 
 
+def get_args(func):
+    """Return a tuple of argument names for a function."""
+    return inspect.getargspec(func).args
+
+
+def _callable(obj):
+    """Checks that an object is callable, else raises a ``MarshallingError``.
+    """
+    if not callable(obj):
+        raise MarshallingError('Object {0!r} is not callable.'.format(obj))
+    return obj
+
+
 class Method(Raw):
     """A field that takes the value returned by a Serializer method.
 
@@ -584,27 +603,40 @@ class Method(Raw):
     @validated
     def output(self, key, obj):
         try:
-            return getattr(self.parent, self.method_name)(obj)
+            method = _callable(getattr(self.parent, self.method_name, None))
+            if len(get_args(method)) > 2:
+                if self.parent.context is None:
+                    msg = 'No context available for Method field {0!r}'.format(key)
+                    raise MarshallingError(msg)
+                return method(obj, self.parent.context)
+            else:
+                return method(obj)
         except AttributeError:
             pass
 
 
 class Function(Raw):
-    '''A field that takes the value returned by a function.
+    """A field that takes the value returned by a function.
 
     :param function func: A callable function from which to retrieve the value.
         The function must take a single argument ``obj`` which is the object
         to be serialized.
-    '''
+    """
 
     def __init__(self, func, **kwargs):
         super(Function, self).__init__(**kwargs)
-        self.func = func
+        self.func = _callable(func)
 
     @validated
     def output(self, key, obj):
         try:
-            return self.func(obj)
+            if len(get_args(self.func)) > 1:
+                if self.parent.context is None:
+                    msg = 'No context available for Function field {0!r}'.format(key)
+                    raise MarshallingError(msg)
+                return self.func(obj, self.parent.context)
+            else:
+                return self.func(obj)
         except TypeError as te:  # Function is not callable
             raise MarshallingError(te)
         except AttributeError:  # the object is not expected to have the attribute
